Note - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Note

A `betty.model.ancestry.Note` attaches arbitrary text to other entities.

## Fields

Notes inherit from:

- Privacy

`entity` (any entity)

  The entity this note is attached to.

`id` (`str`)

  The note’s own entity ID.

`text` (`str`)

  The human-readable note text.